import json
import requests

# announce start
print("Fetching basetype info . . .",end=" ")

# base weapons names 
WEAPON_LIST = ["Sword", "Axe", "Dagger", "Staff", "Bow", "Wand", "Mace"]
ITEM_BASE_TYPES_URL = "https://raw.githubusercontent.com/brather1ng/RePoE/master/RePoE/data/base_items.json"

# combind slots for all weapon types to have a single slot "weapons"
def slot_sub(key,value):
    if any(item in value for item in WEAPON_LIST):
        value = "Weapon"
    return [key,value]

# fetch basetypes
r = requests.get(ITEM_BASE_TYPES_URL)
base_type_dict = dict(json.loads(r.content))

# concat into list of basetype&class
BASE_TYPES = dict([[base_type_dict[base_type]["name"],base_type_dict[base_type]["item_class"]] for base_type in base_type_dict if base_type_dict[base_type]["domain"] == "item"])
# build slot list
SLOT_LOOKUP = dict([slot_sub(k,v) for k,v in BASE_TYPES.items()])

# TODO reduce excess string check by narrowing down this list 
"""Body Armours"""
WEAPON_CLASSES = [v for v in BASE_TYPES.items() if any(item in v for item in WEAPON_LIST)]

print("done")

if __name__ == "__main__":
    # print(SLOT_LOOKUP)
    # print(base_type_dict)
    print(WEAPON_CLASSES)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main_gui.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(717, 357)
        font = QtGui.QFont()
        font.setFamily("Roboto")
        MainWindow.setFont(font)
        MainWindow.setStyleSheet("")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setStyleSheet("")
        self.centralwidget.setObjectName("centralwidget")
        self.login_link = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.login_link.setGeometry(QtCore.QRect(0, -5, 241, 51))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(16)
        font.setBold(False)
        font.setWeight(50)
        self.login_link.setFont(font)
        self.login_link.setAutoFillBackground(False)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("../../../../chipys_pathofexile_chaos_tool/cpct/cpct/img/poe.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.login_link.setIcon(icon)
        self.login_link.setIconSize(QtCore.QSize(40, 40))
        self.login_link.setAutoRepeatDelay(1000)
        self.login_link.setObjectName("login_link")
        self.select_tab = QtWidgets.QComboBox(self.centralwidget)
        self.select_tab.setGeometry(QtCore.QRect(90, 110, 241, 22))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.select_tab.setFont(font)
        self.select_tab.setEditable(True)
        self.select_tab.setObjectName("select_tab")
        self.select_league = QtWidgets.QComboBox(self.centralwidget)
        self.select_league.setGeometry(QtCore.QRect(90, 80, 241, 22))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.select_league.setFont(font)
        self.select_league.setEditable(True)
        self.select_league.setObjectName("select_league")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(10, 80, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(10, 110, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.count_report_string = QtWidgets.QLabel(self.centralwidget)
        self.count_report_string.setGeometry(QtCore.QRect(10, 280, 701, 41))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(14)
        self.count_report_string.setFont(font)
        self.count_report_string.setObjectName("count_report_string")
        self.refresh_link = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.refresh_link.setGeometry(QtCore.QRect(240, -5, 91, 51))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(16)
        font.setBold(False)
        font.setWeight(50)
        self.refresh_link.setFont(font)
        self.refresh_link.setAutoFillBackground(False)
        icon = QtGui.QIcon.fromTheme("refresh")
        self.refresh_link.setIcon(icon)
        self.refresh_link.setIconSize(QtCore.QSize(40, 40))
        self.refresh_link.setAutoRepeatDelay(1000)
        self.refresh_link.setObjectName("refresh_link")
        self.count_weapons = QtWidgets.QProgressBar(self.centralwidget)
        self.count_weapons.setGeometry(QtCore.QRect(340, 10, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_weapons.setFont(font)
        self.count_weapons.setStyleSheet("QProgressBar::chunk {\n"
"    background-color: #05B8CC;\n"
"    border-radius: 8px;\n"
"}\n"
"QProgressBar {\n"
"    text-align: center;\n"
"    border-radius: 8px;\n"
"}")
        self.count_weapons.setProperty("value", 25)
        self.count_weapons.setObjectName("count_weapons")
        self.count_helmets = QtWidgets.QProgressBar(self.centralwidget)
        self.count_helmets.setGeometry(QtCore.QRect(340, 40, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_helmets.setFont(font)
        self.count_helmets.setStyleSheet("QProgressBar::chunk {\n"
"    background-color: #05B8CC;\n"
"    border-radius: 8px;\n"
"}\n"
"QProgressBar {\n"
"    text-align: center;\n"
"    border-radius: 8px;\n"
"}")
        self.count_helmets.setProperty("value", 25)
        self.count_helmets.setObjectName("count_helmets")
        self.count_bodies = QtWidgets.QProgressBar(self.centralwidget)
        self.count_bodies.setGeometry(QtCore.QRect(340, 70, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_bodies.setFont(font)
        self.count_bodies.setStyleSheet("QProgressBar::chunk {\n"
"    background-color: #05B8CC;\n"
"    border-radius: 8px;\n"
"}\n"
"QProgressBar {\n"
"    text-align: center;\n"
"    border-radius: 8px;\n"
"}")
        self.count_bodies.setProperty("value", 25)
        self.count_bodies.setObjectName("count_bodies")
        self.count_amulets = QtWidgets.QProgressBar(self.centralwidget)
        self.count_amulets.setGeometry(QtCore.QRect(340, 190, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_amulets.setFont(font)
        self.count_amulets.setStyleSheet("QProgressBar::chunk {\n"
"    background-color: #05B8CC;\n"
"    border-radius: 8px;\n"
"}\n"
"QProgressBar {\n"
"    text-align: center;\n"
"    border-radius: 8px;\n"
"}")
        self.count_amulets.setProperty("value", 25)
        self.count_amulets.setObjectName("count_amulets")
        self.count_boots = QtWidgets.QProgressBar(self.centralwidget)
        self.count_boots.setGeometry(QtCore.QRect(340, 100, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_boots.setFont(font)
        self.count_boots.setStyleSheet("QProgressBar::chunk {\n"
"    background-color: #05B8CC;\n"
"    border-radius: 8px;\n"
"}\n"
"QProgressBar {\n"
"    text-align: center;\n"
"    border-radius: 8px;\n"
"}")
        self.count_boots.setProperty("value", 25)
        self.count_boots.setObjectName("count_boots")
        self.count_gloves = QtWidgets.QProgressBar(self.centralwidget)
        self.count_gloves.setGeometry(QtCore.QRect(340, 130, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_gloves.setFont(font)
        self.count_gloves.setStyleSheet("QProgressBar::chunk {\n"
"    background-color: #05B8CC;\n"
"    border-radius: 8px;\n"
"}\n"
"QProgressBar {\n"
"    text-align: center;\n"
"    border-radius: 8px;\n"
"}")
        self.count_gloves.setProperty("value", 25)
        self.count_gloves.setObjectName("count_gloves")
        self.count_belts = QtWidgets.QProgressBar(self.centralwidget)
        self.count_belts.setGeometry(QtCore.QRect(340, 160, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_belts.setFont(font)
        self.count_belts.setStyleSheet("QProgressBar::chunk {\n"
"    background-color: #05B8CC;\n"
"    border-radius: 8px;\n"
"}\n"
"QProgressBar {\n"
"    text-align: center;\n"
"    border-radius: 8px;\n"
"}")
        self.count_belts.setProperty("value", 25)
        self.count_belts.setObjectName("count_belts")
        self.count_rings = QtWidgets.QProgressBar(self.centralwidget)
        self.count_rings.setGeometry(QtCore.QRect(340, 220, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_rings.setFont(font)
        self.count_rings.setStyleSheet("\n"
"QProgressBar {\n"
"    text-align: center;\n"
"    border-radius: 8px;\n"
"}\n"
"QProgressBar::chunk {\n"
"    background-color: #05B8CC;\n"
"    border-radius: 6px;\n"
"}")
        self.count_rings.setProperty("value", 25)
        self.count_rings.setObjectName("count_rings")
        self.sets_target = QtWidgets.QSpinBox(self.centralwidget)
        self.sets_target.setGeometry(QtCore.QRect(280, 230, 51, 22))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.sets_target.setFont(font)
        self.sets_target.setProperty("value", 8)
        self.sets_target.setObjectName("sets_target")
        self.label_11 = QtWidgets.QLabel(self.centralwidget)
        self.label_11.setGeometry(QtCore.QRect(200, 230, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.item_ = QtWidgets.QLabel(self.centralwidget)
        self.item_.setGeometry(QtCore.QRect(10, 140, 81, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.item_.setFont(font)
        self.item_.setObjectName("item_")
        self.item_1 = QtWidgets.QLabel(self.centralwidget)
        self.item_1.setEnabled(True)
        self.item_1.setGeometry(QtCore.QRect(10, 200, 91, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.item_1.setFont(font)
        self.item_1.setObjectName("item_1")
        self.filter_mode = QtWidgets.QComboBox(self.centralwidget)
        self.filter_mode.setEnabled(True)
        self.filter_mode.setGeometry(QtCore.QRect(110, 200, 221, 22))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.filter_mode.setFont(font)
        self.filter_mode.setObjectName("filter_mode")
        self.item_2 = QtWidgets.QLabel(self.centralwidget)
        self.item_2.setEnabled(False)
        self.item_2.setGeometry(QtCore.QRect(10, 230, 111, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.item_2.setFont(font)
        self.item_2.setObjectName("item_2")
        self.recipe_chaos = QtWidgets.QRadioButton(self.centralwidget)
        self.recipe_chaos.setEnabled(False)
        self.recipe_chaos.setGeometry(QtCore.QRect(70, 230, 91, 17))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(10)
        self.recipe_chaos.setFont(font)
        self.recipe_chaos.setChecked(True)
        self.recipe_chaos.setObjectName("recipe_chaos")
        self.recipe_type = QtWidgets.QButtonGroup(MainWindow)
        self.recipe_type.setObjectName("recipe_type")
        self.recipe_type.addButton(self.recipe_chaos)
        self.recipe_regal = QtWidgets.QRadioButton(self.centralwidget)
        self.recipe_regal.setEnabled(False)
        self.recipe_regal.setGeometry(QtCore.QRect(70, 250, 91, 17))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(10)
        self.recipe_regal.setFont(font)
        self.recipe_regal.setObjectName("recipe_regal")
        self.recipe_type.addButton(self.recipe_regal)
        self.item_filter_browse = QtWidgets.QPushButton(self.centralwidget)
        self.item_filter_browse.setGeometry(QtCore.QRect(90, 140, 241, 23))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(10)
        self.item_filter_browse.setFont(font)
        self.item_filter_browse.setObjectName("item_filter_browse")
        self.client_secret_input = QtWidgets.QLineEdit(self.centralwidget)
        self.client_secret_input.setGeometry(QtCore.QRect(90, 50, 241, 20))
        self.client_secret_input.setObjectName("client_secret_input")
        self.label_13 = QtWidgets.QLabel(self.centralwidget)
        self.label_13.setGeometry(QtCore.QRect(10, 50, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_13.setFont(font)
        self.label_13.setObjectName("label_13")
        self.client_path_browse = QtWidgets.QPushButton(self.centralwidget)
        self.client_path_browse.setGeometry(QtCore.QRect(100, 170, 231, 23))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(10)
        self.client_path_browse.setFont(font)
        self.client_path_browse.setObjectName("client_path_browse")
        self.item_3 = QtWidgets.QLabel(self.centralwidget)
        self.item_3.setGeometry(QtCore.QRect(10, 170, 91, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.item_3.setFont(font)
        self.item_3.setObjectName("item_3")
        self.color_link_rings = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.color_link_rings.setGeometry(QtCore.QRect(610, 210, 101, 31))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.color_link_rings.sizePolicy().hasHeightForWidth())
        self.color_link_rings.setSizePolicy(sizePolicy)
        self.color_link_rings.setSizeIncrement(QtCore.QSize(0, 0))
        self.color_link_rings.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.color_link_rings.setFont(font)
        self.color_link_rings.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.color_link_rings.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.color_link_rings.setAutoFillBackground(False)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("../img/dropper.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.color_link_rings.setIcon(icon1)
        self.color_link_rings.setIconSize(QtCore.QSize(20, 20))
        self.color_link_rings.setAutoRepeatDelay(1000)
        self.color_link_rings.setObjectName("color_link_rings")
        self.color_link_amulets = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.color_link_amulets.setGeometry(QtCore.QRect(610, 180, 101, 31))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.color_link_amulets.sizePolicy().hasHeightForWidth())
        self.color_link_amulets.setSizePolicy(sizePolicy)
        self.color_link_amulets.setSizeIncrement(QtCore.QSize(0, 0))
        self.color_link_amulets.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.color_link_amulets.setFont(font)
        self.color_link_amulets.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.color_link_amulets.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.color_link_amulets.setAutoFillBackground(False)
        self.color_link_amulets.setIcon(icon1)
        self.color_link_amulets.setIconSize(QtCore.QSize(20, 20))
        self.color_link_amulets.setAutoRepeatDelay(1000)
        self.color_link_amulets.setObjectName("color_link_amulets")
        self.color_link_belts = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.color_link_belts.setGeometry(QtCore.QRect(610, 150, 101, 31))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.color_link_belts.sizePolicy().hasHeightForWidth())
        self.color_link_belts.setSizePolicy(sizePolicy)
        self.color_link_belts.setSizeIncrement(QtCore.QSize(0, 0))
        self.color_link_belts.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.color_link_belts.setFont(font)
        self.color_link_belts.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.color_link_belts.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.color_link_belts.setAutoFillBackground(False)
        self.color_link_belts.setIcon(icon1)
        self.color_link_belts.setIconSize(QtCore.QSize(20, 20))
        self.color_link_belts.setAutoRepeatDelay(1000)
        self.color_link_belts.setObjectName("color_link_belts")
        self.color_link_gloves = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.color_link_gloves.setGeometry(QtCore.QRect(610, 120, 101, 31))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.color_link_gloves.sizePolicy().hasHeightForWidth())
        self.color_link_gloves.setSizePolicy(sizePolicy)
        self.color_link_gloves.setSizeIncrement(QtCore.QSize(0, 0))
        self.color_link_gloves.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.color_link_gloves.setFont(font)
        self.color_link_gloves.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.color_link_gloves.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.color_link_gloves.setAutoFillBackground(False)
        self.color_link_gloves.setIcon(icon1)
        self.color_link_gloves.setIconSize(QtCore.QSize(20, 20))
        self.color_link_gloves.setAutoRepeatDelay(1000)
        self.color_link_gloves.setObjectName("color_link_gloves")
        self.color_link_helmets = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.color_link_helmets.setGeometry(QtCore.QRect(610, 30, 101, 31))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.color_link_helmets.sizePolicy().hasHeightForWidth())
        self.color_link_helmets.setSizePolicy(sizePolicy)
        self.color_link_helmets.setSizeIncrement(QtCore.QSize(0, 0))
        self.color_link_helmets.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.color_link_helmets.setFont(font)
        self.color_link_helmets.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.color_link_helmets.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.color_link_helmets.setAutoFillBackground(False)
        self.color_link_helmets.setIcon(icon1)
        self.color_link_helmets.setIconSize(QtCore.QSize(20, 20))
        self.color_link_helmets.setAutoRepeatDelay(1000)
        self.color_link_helmets.setObjectName("color_link_helmets")
        self.color_link_bodies = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.color_link_bodies.setGeometry(QtCore.QRect(610, 60, 101, 31))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.color_link_bodies.sizePolicy().hasHeightForWidth())
        self.color_link_bodies.setSizePolicy(sizePolicy)
        self.color_link_bodies.setSizeIncrement(QtCore.QSize(0, 0))
        self.color_link_bodies.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.color_link_bodies.setFont(font)
        self.color_link_bodies.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.color_link_bodies.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.color_link_bodies.setAutoFillBackground(False)
        self.color_link_bodies.setIcon(icon1)
        self.color_link_bodies.setIconSize(QtCore.QSize(20, 20))
        self.color_link_bodies.setAutoRepeatDelay(1000)
        self.color_link_bodies.setObjectName("color_link_bodies")
        self.color_link_boots = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.color_link_boots.setGeometry(QtCore.QRect(610, 90, 101, 31))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.color_link_boots.sizePolicy().hasHeightForWidth())
        self.color_link_boots.setSizePolicy(sizePolicy)
        self.color_link_boots.setSizeIncrement(QtCore.QSize(0, 0))
        self.color_link_boots.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.color_link_boots.setFont(font)
        self.color_link_boots.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.color_link_boots.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.color_link_boots.setAutoFillBackground(False)
        self.color_link_boots.setIcon(icon1)
        self.color_link_boots.setIconSize(QtCore.QSize(20, 20))
        self.color_link_boots.setAutoRepeatDelay(1000)
        self.color_link_boots.setObjectName("color_link_boots")
        self.color_link_weapons = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.color_link_weapons.setGeometry(QtCore.QRect(610, 0, 111, 31))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.color_link_weapons.sizePolicy().hasHeightForWidth())
        self.color_link_weapons.setSizePolicy(sizePolicy)
        self.color_link_weapons.setSizeIncrement(QtCore.QSize(0, 0))
        self.color_link_weapons.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.color_link_weapons.setFont(font)
        self.color_link_weapons.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.color_link_weapons.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.color_link_weapons.setAutoFillBackground(False)
        self.color_link_weapons.setIcon(icon1)
        self.color_link_weapons.setIconSize(QtCore.QSize(20, 20))
        self.color_link_weapons.setAutoRepeatDelay(1000)
        self.color_link_weapons.setObjectName("color_link_weapons")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 717, 21))
        self.menubar.setObjectName("menubar")
        self.menuLinks = QtWidgets.QMenu(self.menubar)
        self.menuLinks.setObjectName("menuLinks")
        self.menuSettings = QtWidgets.QMenu(self.menubar)
        self.menuSettings.setObjectName("menuSettings")
        self.menuAbout = QtWidgets.QMenu(self.menubar)
        self.menuAbout.setObjectName("menuAbout")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionFilterblade_xyz = QtWidgets.QAction(MainWindow)
        self.actionFilterblade_xyz.setObjectName("actionFilterblade_xyz")
        self.actionChipy_dev = QtWidgets.QAction(MainWindow)
        self.actionChipy_dev.setObjectName("actionChipy_dev")
        self.actionPathOfExile_com = QtWidgets.QAction(MainWindow)
        self.actionPathOfExile_com.setObjectName("actionPathOfExile_com")
        self.actionPathOfBuilding_com = QtWidgets.QAction(MainWindow)
        self.actionPathOfBuilding_com.setObjectName("actionPathOfBuilding_com")
        self.actionCraftOfExile_com = QtWidgets.QAction(MainWindow)
        self.actionCraftOfExile_com.setObjectName("actionCraftOfExile_com")
        self.actionMap_RegEx = QtWidgets.QAction(MainWindow)
        self.actionMap_RegEx.setObjectName("actionMap_RegEx")
        self.actionVorici_Calculator = QtWidgets.QAction(MainWindow)
        self.actionVorici_Calculator.setObjectName("actionVorici_Calculator")
        self.actionPoE_Ninja = QtWidgets.QAction(MainWindow)
        self.actionPoE_Ninja.setObjectName("actionPoE_Ninja")
        self.actionPoE_Lab = QtWidgets.QAction(MainWindow)
        self.actionPoE_Lab.setObjectName("actionPoE_Lab")
        self.actionAwakened_PoE_Trade = QtWidgets.QAction(MainWindow)
        self.actionAwakened_PoE_Trade.setObjectName("actionAwakened_PoE_Trade")
        self.actionInput_ClientSecret = QtWidgets.QAction(MainWindow)
        self.actionInput_ClientSecret.setEnabled(True)
        self.actionInput_ClientSecret.setObjectName("actionInput_ClientSecret")
        self.actionGitHub = QtWidgets.QAction(MainWindow)
        self.actionGitHub.setObjectName("actionGitHub")
        self.actionPatreon = QtWidgets.QAction(MainWindow)
        self.actionPatreon.setObjectName("actionPatreon")
        self.action_NOT_AFFILIATED_WITH_ANY = QtWidgets.QAction(MainWindow)
        self.action_NOT_AFFILIATED_WITH_ANY.setObjectName("action_NOT_AFFILIATED_WITH_ANY")
        self.menuLinks.addAction(self.action_NOT_AFFILIATED_WITH_ANY)
        self.menuLinks.addSeparator()
        self.menuLinks.addAction(self.actionPathOfExile_com)
        self.menuLinks.addAction(self.actionPathOfBuilding_com)
        self.menuLinks.addAction(self.actionCraftOfExile_com)
        self.menuLinks.addAction(self.actionFilterblade_xyz)
        self.menuLinks.addAction(self.actionMap_RegEx)
        self.menuLinks.addAction(self.actionVorici_Calculator)
        self.menuLinks.addAction(self.actionPoE_Ninja)
        self.menuLinks.addAction(self.actionPoE_Lab)
        self.menuLinks.addAction(self.actionAwakened_PoE_Trade)
        self.menuSettings.addAction(self.actionInput_ClientSecret)
        self.menuAbout.addAction(self.actionChipy_dev)
        self.menuAbout.addAction(self.actionGitHub)
        self.menuAbout.addAction(self.actionPatreon)
        self.menubar.addAction(self.menuSettings.menuAction())
        self.menubar.addAction(self.menuLinks.menuAction())
        self.menubar.addAction(self.menuAbout.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Chipys PathOfExile Choas Tool"))
        self.login_link.setStatusTip(_translate("MainWindow", "Path of Exile sign-in (permissions to read your stash)"))
        self.login_link.setText(_translate("MainWindow", "Log In?"))
        self.label.setText(_translate("MainWindow", "League:"))
        self.label_2.setText(_translate("MainWindow", "Tab:"))
        self.count_report_string.setText(_translate("MainWindow", "TextLabel"))
        self.refresh_link.setStatusTip(_translate("MainWindow", "Manually refresh item counts (Stash only updates after joining a new zone)"))
        self.refresh_link.setText(_translate("MainWindow", "Refresh"))
        self.sets_target.setStatusTip(_translate("MainWindow", "Number of sets to be collecting (for show progress)"))
        self.label_11.setText(_translate("MainWindow", "Set goal:"))
        self.item_.setText(_translate("MainWindow", "Item Fitler:"))
        self.item_1.setText(_translate("MainWindow", "Filter Mode:"))
        self.filter_mode.setStatusTip(_translate("MainWindow", "How to interact with filter (Disabled to leave filters alone)"))
        self.item_2.setText(_translate("MainWindow", "Recipe:"))
        self.recipe_chaos.setStatusTip(_translate("MainWindow", "Chaos Recipe: Unidentified set of all items iLevel +60"))
        self.recipe_chaos.setText(_translate("MainWindow", "Chaos (i60+)"))
        self.recipe_regal.setStatusTip(_translate("MainWindow", "Regal Recipe: Unidentified set of all items iLevel +70"))
        self.recipe_regal.setText(_translate("MainWindow", "Regal (i70+)"))
        self.item_filter_browse.setStatusTip(_translate("MainWindow", "Select the item filter you use or what to modify for Chaos Recipe"))
        self.item_filter_browse.setText(_translate("MainWindow", "Browse"))
        self.client_secret_input.setStatusTip(_translate("MainWindow", "Your client secret, never share this!"))
        self.label_13.setText(_translate("MainWindow", "SECRET:"))
        self.client_path_browse.setStatusTip(_translate("MainWindow", "Browse to your \'Path of Exile\' folder install location"))
        self.client_path_browse.setText(_translate("MainWindow", "Browse"))
        self.item_3.setText(_translate("MainWindow", "PoE Folder:"))
        self.color_link_rings.setStatusTip(_translate("MainWindow", "Select the base background color to use in itemFilter"))
        self.color_link_rings.setText(_translate("MainWindow", "Rings"))
        self.color_link_amulets.setStatusTip(_translate("MainWindow", "Select the base background color to use in itemFilter"))
        self.color_link_amulets.setText(_translate("MainWindow", "Amulets"))
        self.color_link_belts.setStatusTip(_translate("MainWindow", "Select the base background color to use in itemFilter"))
        self.color_link_belts.setText(_translate("MainWindow", "Belts"))
        self.color_link_gloves.setStatusTip(_translate("MainWindow", "Select the base background color to use in itemFilter"))
        self.color_link_gloves.setText(_translate("MainWindow", "Gloves"))
        self.color_link_helmets.setStatusTip(_translate("MainWindow", "Select the base background color to use in itemFilter"))
        self.color_link_helmets.setText(_translate("MainWindow", "Helmets"))
        self.color_link_bodies.setStatusTip(_translate("MainWindow", "Select the base background color to use in itemFilter"))
        self.color_link_bodies.setText(_translate("MainWindow", "Bodies"))
        self.color_link_boots.setStatusTip(_translate("MainWindow", "Select the base background color to use in itemFilter"))
        self.color_link_boots.setText(_translate("MainWindow", "Boots"))
        self.color_link_weapons.setStatusTip(_translate("MainWindow", "Select the base background color to use in itemFilter"))
        self.color_link_weapons.setText(_translate("MainWindow", "Weapons"))
        self.menuLinks.setTitle(_translate("MainWindow", "Community Tools"))
        self.menuSettings.setTitle(_translate("MainWindow", "Settings"))
        self.menuAbout.setTitle(_translate("MainWindow", "About"))
        self.actionFilterblade_xyz.setText(_translate("MainWindow", "Filterblade.xyz"))
        self.actionChipy_dev.setText(_translate("MainWindow", "Chipy.dev"))
        self.actionPathOfExile_com.setText(_translate("MainWindow", "Path of Exile (Official)"))
        self.actionPathOfBuilding_com.setText(_translate("MainWindow", "Path of Building"))
        self.actionCraftOfExile_com.setText(_translate("MainWindow", "Craft of Exile"))
        self.actionMap_RegEx.setText(_translate("MainWindow", "Map RegEx"))
        self.actionVorici_Calculator.setText(_translate("MainWindow", "Vorici Calculator"))
        self.actionPoE_Ninja.setText(_translate("MainWindow", "PoE Ninja"))
        self.actionPoE_Lab.setText(_translate("MainWindow", "PoE Lab"))
        self.actionAwakened_PoE_Trade.setText(_translate("MainWindow", "Awakened PoE Trade"))
        self.actionInput_ClientSecret.setText(_translate("MainWindow", "Request ClientSecret"))
        self.actionGitHub.setText(_translate("MainWindow", "GitHub"))
        self.actionPatreon.setText(_translate("MainWindow", "Patreon"))
        self.action_NOT_AFFILIATED_WITH_ANY.setText(_translate("MainWindow", "*NOT AFFILIATED"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())



import typing
import datetime
import os
import sys
import time
import webbrowser
from PyQt5.QtWidgets import QMainWindow, QFileDialog, QApplication, QColorDialog, QInputDialog, QWidget
from PyQt5 import QtGui
from PyQt5.QtCore import QTimer
import qt.main_gui
import ctypes
import poepy
import user_info
from __about__ import __version__

# type checking block (AND RUFF INFO)
# https://www.youtube.com/watch?v=bcAqceZkZRQ
if typing.TYPE_CHECKING:
    ...

# set statics
ASYNC_INTERVAL_MS = 1000
PROGRESS_BAR_STYLE = """
QProgressBar {
	text-align: center;
	border-radius: 8px;
}
QProgressBar::chunk {
	background-color: #05B8CC;
	border-radius: 6px;
}
"""

api:poepy.PoeApiHandler
parser:poepy.DataParser

# variables for searching log files to detect new zone
modified = 0
async_time = time.time()
previous = 0
refresh_off_cooldown = True

class AsyncMainWindow(QMainWindow):
    log_timer = QTimer()
    def __init__(self):
        super().__init__()
        self.init_async()

    def init_async(self):
        print("Initializing . . . ", end="")
        self.log_timer.timeout.connect(async_two)
        self.log_timer.start(ASYNC_INTERVAL_MS)
        print("Started")

def try_wrapper(function):
    """Simple wrapper that includes a TRY loop
    Args:
        function (Func): Returns the provided function wrapped Try
    """
    def wrapper(*args, **kwargs):
        try:
            return function(*args, **kwargs)
        except Exception as e:
            print(function.__name__, "=> FAILED:", e)
            return False
    return wrapper  

def timed_try_wrapper(function):
    """Simple timing wrapper that also includes a TRY loop
    Args:
        function (Func): Returns the provided function wrapped with Time and Try
    """
    def wrapper(*args, **kwargs):
        start = time.time()
        try:
            result = function(*args, **kwargs)
            end = time.time()
            print(function.__name__, "=> RunTime:",end-start)
            return result
        except Exception as e:
            end = time.time()
            print(function.__name__, "=> FAILED:",end-start, e)
            result = False
    return wrapper    

def apply_ui_defaults():
    global gui_main

    # set previous selections
    gui_main.item_filter_browse.setText(os.path.split(user_info.get("form", "filter_name"))[1])
    gui_main.client_secret_input.setText(user_info.get("api","client_secret"))
    gui_main.client_path_browse.setText(user_info.get("form", "client_path")[0:22]+"..."+user_info.get("form", "client_path")[-13:])
    gui_main.sets_target.setValue(int(user_info.get("form", "sets_goal")))

    # set previous colours
    gui_main.count_amulets.setStyleSheet(style_sheet_new_color(PROGRESS_BAR_STYLE, user_info.get("form", "color_amulets")))
    gui_main.count_belts.setStyleSheet(style_sheet_new_color(PROGRESS_BAR_STYLE, user_info.get("form", "color_amulets")))
    gui_main.count_bodies.setStyleSheet(style_sheet_new_color(PROGRESS_BAR_STYLE, user_info.get("form", "color_bodies")))
    gui_main.count_boots.setStyleSheet(style_sheet_new_color(PROGRESS_BAR_STYLE, user_info.get("form", "color_boots")))
    gui_main.count_gloves.setStyleSheet(style_sheet_new_color(PROGRESS_BAR_STYLE, user_info.get("form", "color_gloves")))
    gui_main.count_helmets.setStyleSheet(style_sheet_new_color(PROGRESS_BAR_STYLE, user_info.get("form", "color_helmets")))
    gui_main.count_rings.setStyleSheet(style_sheet_new_color(PROGRESS_BAR_STYLE, user_info.get("form", "color_rings")))
    gui_main.count_weapons.setStyleSheet(style_sheet_new_color(PROGRESS_BAR_STYLE, user_info.get("form", "color_weapons")))

    # defaults for item_filter modes
    gui_main.filter_mode.addItems(["Default","FilterBlade","Custom","Disabled"])
    
def apply_ui_connections():
    """Overlay that connects up the GUI so that we can modularly replace the gui.py from QT5
    https://www.geeksforgeeks.org/function-wrappers-in-python/
    Args:
        gui_obj (gui.Ui_MainWindow): Main window GUI object
    """
    global gui_main, MainWindow

    # set window Icons
    app.setWindowIcon(QtGui.QIcon('./cpct/cpct/img/ChipyLogo.png'))
    MainWindow.setWindowTitle(f"Chipy's PoE Chaos Tool (v{__version__})")
    
    # set login icon (this is to fix the image path issue)
    icon = QtGui.QIcon()
    icon.addPixmap(QtGui.QPixmap("./cpct/cpct/img/poe.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    gui_main.login_link.setIcon(icon)
    icon.addPixmap(QtGui.QPixmap("./cpct/cpct/img/dropper.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    gui_main.color_link_rings.setIcon(icon)
    gui_main.color_link_amulets.setIcon(icon)
    gui_main.color_link_belts.setIcon(icon)
    gui_main.color_link_bodies.setIcon(icon)
    gui_main.color_link_boots.setIcon(icon)
    gui_main.color_link_helmets.setIcon(icon)
    gui_main.color_link_weapons.setIcon(icon)
    gui_main.color_link_gloves.setIcon(icon)

    # Link ColorPickers
    gui_main.color_link_amulets.clicked.connect(lambda: pick_color( gui_main.count_amulets, "color_amulets"))
    gui_main.color_link_belts.clicked.connect(lambda: pick_color( gui_main.count_belts, "color_belts"))
    gui_main.color_link_bodies.clicked.connect(lambda: pick_color( gui_main.count_bodies, "color_bodies"))
    gui_main.color_link_boots.clicked.connect(lambda: pick_color( gui_main.count_boots, "color_boots"))
    gui_main.color_link_gloves.clicked.connect(lambda: pick_color( gui_main.count_gloves, "color_gloves"))
    gui_main.color_link_helmets.clicked.connect(lambda: pick_color( gui_main.count_helmets, "color_helmets"))
    gui_main.color_link_rings.clicked.connect(lambda: pick_color( gui_main.count_rings, "color_rings"))
    gui_main.color_link_weapons.clicked.connect(lambda: pick_color( gui_main.count_weapons, "color_weapons"))

    # # link menus
    gui_main.actionChipy_dev.triggered.connect(lambda: webbrowser.open("www.chipy.dev/me.html"))
    gui_main.actionGitHub.triggered.connect(lambda: webbrowser.open("https://github.com/iamchipy/chipys-pathofexile-chaos-tool/tree/main/cpct"))
    gui_main.actionFilterblade_xyz.triggered.connect(lambda: webbrowser.open("https://www.filterblade.xyz/") )
    gui_main.actionCraftOfExile_com.triggered.connect(lambda: webbrowser.open("https://www.craftofexile.com/en/") )
    gui_main.actionMap_RegEx.triggered.connect(lambda: webbrowser.open("https://poe.re/#/maps") )
    gui_main.actionPathOfBuilding_com.triggered.connect(lambda: webbrowser.open("https://pathofbuilding.community/") )
    gui_main.actionPathOfExile_com.triggered.connect(lambda: webbrowser.open("https://www.pathofexile.com") )
    gui_main.actionPoE_Lab.triggered.connect(lambda: webbrowser.open("https://www.poelab.com/") )
    gui_main.actionPoE_Ninja.triggered.connect(lambda: webbrowser.open("https://www.poe.ninja") )
    gui_main.actionVorici_Calculator.triggered.connect(lambda: webbrowser.open("https://siveran.github.io/calc.html") )
    gui_main.actionAwakened_PoE_Trade.triggered.connect(lambda: webbrowser.open("https://github.com/SnosMe/awakened-poe-trade") )
    gui_main.actionPatreon.triggered.connect(lambda: webbrowser.open("https://www.patreon.com/chipysPoEChaosTool") )
    gui_main.actionInput_ClientSecret.triggered.connect(lambda: request_client_secret() )
    
    #ClientSecrect Menu
    # gui_main.actionInput_ClientSecret.triggered.connect(lambda: receive_client_secret(gui_main) )

    # # link buttons
    gui_main.login_link.clicked.connect(lambda: action_login_link(gui_main))
    gui_main.refresh_link.clicked.connect(lambda: update_unid_counts(gui_main, True))
    gui_main.item_filter_browse.clicked.connect(lambda: browser_item_filters(gui_main))
    gui_main.client_path_browse.clicked.connect(lambda: browser_client_folder(gui_main))

    # Link ComboBoxes
    gui_main.select_league.currentIndexChanged.connect(lambda: action_set_league(gui_main))
    gui_main.select_tab.currentIndexChanged.connect(lambda: action_set_tab(gui_main))
    gui_main.filter_mode.currentIndexChanged.connect(lambda: update_item_filter(gui_main))
    gui_main.sets_target.valueChanged.connect(lambda: change_target_count(gui_main))

    # Link Text
    gui_main.client_secret_input.textChanged.connect(lambda: receive_client_secret(gui_main))

@timed_try_wrapper
def action_login_link(gui):
    global api, parser, gui_main
    api = poepy.PoeApiHandler(client_id=user_info.cfg["api"]["CLIENT_ID"],
                                    client_secret=user_info.cfg["api"]["CLIENT_SECRET"],
                                    scope=user_info.cfg["api"]["SCOPE"],
                                    uri=user_info.cfg["api"]["REDIRECT_URI"],
                                    manual_token=user_info.cfg["api"]["TOKEN"]
                                    )
    parser = poepy.DataParser(api_handler = api)

    # save any token changes
    user_info.set("api","TOKEN", api.token)
    user_info.set("form","username", parser.get_username())
    # gui_main.client_secret_input.isEnabled = False
    gui_main.client_secret_input.setEnabled(False)


    # set login name
    gui.login_link.setText(user_info.get("form","username"))
    gui.login_link.setDisabled(True)
    gui.select_league.setCurrentText( user_info.get("form","league"))
    gui.select_tab.setCurrentText( user_info.get("form","tab"))

    # continue the loading chain
    action_load_leagues(gui)

@timed_try_wrapper
def action_load_leagues(gui):
    global parser
    leagues = parser.get_leagues()

    # clear the box and repop
    gui.select_league.clear()
    gui.select_tab.clear()
    gui.select_league.addItems(leagues)

    # set previous league
    gui_main.select_league.setCurrentText(user_info.get("form","league"))
    
@timed_try_wrapper
def action_set_league(gui):
    # load current selection for league
    league = gui.select_league.currentText()
    # print("League:",league)
    if league != "":
        try:
            previous = user_info.get("form", "league")
            # print("previous:",previous)
            action_load_tabs(gui, previous)
        except Exception as e:
            print("action_set_league::>",e)
            user_info.set("form", "league",gui.select_league.currentText()) 
            action_load_tabs(gui, league)

@timed_try_wrapper
def action_load_tabs(gui, league):
    global parser, gui_main
    tabs = parser.get_tab_names(league).keys()
    # clear the box and repop
    gui.select_tab.clear()
    gui.select_tab.addItems(tabs)
    
@timed_try_wrapper
def action_set_tab(gui, force_recache:bool=False):
    global parser, gui_main
    user_info.set("form", "tab", gui.select_tab.currentText())
  
@timed_try_wrapper
def update_unid_counts(gui, force_recache:bool=False):
    global parser, gui_main, refresh_off_cooldown
    league_of_interest = gui.select_league.currentText()
    refresh_off_cooldown = False
    gui_main.refresh_link.setEnabled(refresh_off_cooldown)

    # TODO Auto filter reload "/itemfilter 0PKKgH0"

    try:
        # tab_of_interes
        tabs_of_interest = poepy.validate_tab(parser, league_of_interest, gui.select_tab.currentText())

        # list of items
        items_of_interest = parser.get_items(tabs_of_interest, league_of_interest, force_recache)

        # filter for unid
        items_unidentified = parser.filter_identified(items_of_interest)

        # filter for ilevel
        items_unidentified_ilvl = parser.filter_ilvl(items_unidentified)
        
        # loop and count unids
        count = poepy.count_slots(parser, items_unidentified_ilvl)
        # gui_main.count_report_string.setText(f"Count Total: {count['Total']}")

        # Set scales and mutlipliers
        target = gui.sets_target.value()
        multiplier = 100//target

        # set GUI element values
        gui_main.count_weapons.setValue(count["Weapon"]*multiplier)
        gui_main.count_helmets.setValue(count["Helmet"]*multiplier)
        gui_main.count_bodies.setValue(count["Body"]*multiplier)
        gui_main.count_boots.setValue(count["Boots"]*multiplier)
        gui_main.count_gloves.setValue(count["Gloves"]*multiplier)
        gui_main.count_belts.setValue(count["Belt"]*multiplier)
        gui_main.count_amulets.setValue(count["Amulet"]*multiplier)
        gui_main.count_rings.setValue((count["Ring"]*multiplier)//2)
    except Exception as e:
        gui.count_report_string.setText("ERR:"+str(e))

def async_two():
    global refresh_off_cooldown, gui_main, async_time
    elapsed = time.time() - async_time
    # Entry point to secondary exec chain
    log_search()
    # Trigger only every 5 sec
    if elapsed>5 and not refresh_off_cooldown:
        refresh_off_cooldown = True 
        gui_main.refresh_link.setEnabled(refresh_off_cooldown)
    if elapsed > 10:
        async_time = time.time()

@try_wrapper
def log_search():
    """Checks the ClientLog for a maching zone change with timestamp in the current minute
    """
    global modified, previous, gui_main
    # 2023/03/30 09:11     
    # 2023/03/30 09:26:41 1117798968 cffb0734 [INFO Client 31504] : You have entered Aspirants' Plaza.     
    snippet = " : You have entered"
    path = user_info.get("form","client_path") + "\logs\Client.txt"
    if not os.path.exists(path):
        return False
    modified = os.path.getmtime(path)
    if modified > previous:
        previous = modified
        # print("Last modified: %s" % time.ctime(modified))
        # gui_main.count_report_string.setText("Reading...")
        stamp = datetime.datetime.now().strftime("%Y/%m/%d %H:%M")
        with open(path, "r", encoding="utf-8") as file:
            for line in file:
                if stamp in line and snippet in line:
                        print(line)
                        gui_main.count_report_string.setText(line[78:])
                        update_unid_counts(gui_main)
                        return
        # gui_main.count_report_string.setText("Reading... Done")

@timed_try_wrapper
def browser_item_filters(gui):
    global MainWindow, gui_main
    #C:\Users\chipy\Documents\My Games\Path of Exile\
    file_dialog = QFileDialog(MainWindow)
    file_dialog.setFileMode(QFileDialog.AnyFile)
    file_dialog.setNameFilter("Item Filter (*.filter)")
    file_dialog.setDirectory(user_info.get("form","filter_dir"))
    
    if file_dialog.exec_():
        path = file_dialog.selectedFiles()[0]
        user_info.set("form", "filter_name", path)
        gui.item_filter_browse.setText(os.path.split(path)[1])

@timed_try_wrapper
def browser_client_folder(gui):
    global MainWindow, gui_main
    file_dialog = QFileDialog(MainWindow)
    path = file_dialog.getExistingDirectory(MainWindow, "Select 'Path of Exile' Folder", "C:\Program Files (x86)\Grinding Gear Games")
    user_info.set("form", "client_path", path)
    gui_main.client_path_browse.setText(path[0:22]+"..."+path[-13:])
    
def receive_client_secret(gui):
    global gui_main
    user_info.set("api","client_secret",gui_main.client_secret_input.text())

@timed_try_wrapper
def pick_color(target_object, save_name):
    current_color = QtGui.QColor(user_info.get("form", save_name))
    new_color = QColorDialog.getColor(current_color, title=f"Pick a new color for {save_name}")
    if new_color.isValid():
        user_info.set("form", save_name, new_color.name())
        user_info.set("form", save_name+"_rgb", str(list(new_color.getRgb())))
        target_object.setStyleSheet(style_sheet_new_color(PROGRESS_BAR_STYLE,new_color.name()))
        update_item_filter()

def style_sheet_new_color(base_style:str,new_color:str) -> str:
    return_string = ""
    i = base_style.find("background-color: ")
    current_color = base_style[i+18:i+25]
    return_string = base_style.replace(current_color, new_color) 
    return return_string

@timed_try_wrapper
def update_item_filter(gui=None):
    global gui_main
    header = poepy.ITEM_FILTER_TITLE_START
    footer = poepy.ITEM_FILTER_TITLE_END
    path = user_info.cfg.get("form","filter_name")
    mode = gui_main.filter_mode.currentText()

    # read data
    current_filter = ""
    is_section_to_replace=False
    with open(path, "r") as f:
        for line in f:
            if header in line:
                is_section_to_replace = True
            elif footer in line:
                is_section_to_replace = False
            if not is_section_to_replace and footer not in line:
                current_filter += line

    # append
   
    prefix = header
    if "Disabled" not in mode:
        prefix += poepy.ItemFilterEntry("Weapons",user_info.cfg.get("form","color_weapons_rgb"),width="= 1").to_str()
        prefix += poepy.ItemFilterEntry("Helmets",user_info.cfg.get("form","color_helmets_rgb")).to_str()
        prefix += poepy.ItemFilterEntry("Body Armours",user_info.cfg.get("form","color_bodies_rgb")).to_str()   
        prefix += poepy.ItemFilterEntry("Boots",user_info.cfg.get("form","color_boots_rgb")).to_str()
        prefix += poepy.ItemFilterEntry("Gloves",user_info.cfg.get("form","color_gloves_rgb")).to_str()
        prefix += poepy.ItemFilterEntry("Amulets",user_info.cfg.get("form","color_amulets_rgb")).to_str()
        prefix += poepy.ItemFilterEntry("Rings",user_info.cfg.get("form","color_rings_rgb")).to_str()
    prefix += footer

    # write
    with open(path, "w") as f:
        f.write(prefix+current_filter)
            
@timed_try_wrapper
def request_client_secret():
    global gui_main
    promt_obj = QWidget()
    discord_name, ok = QInputDialog.getText(promt_obj, 'Send Discord Request?', 'Please provide the Discord name (including full "name#1234") to send the secret to')
    if ok:
        post = poepy.request_secret(discord_name)
        print(post)
        if "20" in str(post):
            gui_main.count_report_string.setText('Request has been send please look out for a friend request on Discord')
            # QInputDialog.getText(promt_obj, 'Request Sent', 'Request has been send please look out for a friend request on Discord')

@timed_try_wrapper
def change_target_count(gui):
    user_info.set("form","sets_goal", str(gui.sets_target.value()))

if __name__ == "__main__":
    # load user file
    user_info.load()

    # required for Windows to recognize a Python script as it's own applications and thus have a unique Taskbar Icon
    # https://stackoverflow.com/questions/1551605/how-to-set-applications-taskbar-icon-in-windows-7/1552105#1552105
    myappid = u'chipy.PoE.chaos.tool' # arbitrary string
    ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(myappid)

    # build main GUI
    app = QApplication(sys.argv)
    app.setStyle('Fusion')
    MainWindow = AsyncMainWindow()
    MainWindow.show()
    gui_main = qt.main_gui.Ui_MainWindow()
    gui_main.setupUi(MainWindow)

    # Modify the gui with connections and links
    apply_ui_connections()  # here we modify actions to the GUI
    apply_ui_defaults()  # set default values for the form when it's made

    # run app as the last thing in the script
    sys.exit(app.exec_())
  


# import private
import configparser
import os

# const
CFG_FILENAME = r"user_settings.cfg"
# CFG info
cfg = configparser.ConfigParser()

def save():
    with open(CFG_FILENAME,"w") as config_file:
        cfg.write(config_file)

def load():
    # Set deafults
    cfg["form"] = {"filter_dir": os.path.expanduser("~/Documents")+"/My Games/Path of Exile/",
                   "filter_name":"Browse To Select",
                   "client_path":"Browse To Select",
                   "username":"",
                   "league":"",
                   "tab":"",
                   "sets_goal":"4",
                   "color_weapons":"#457dff",
                   "color_weapons_rgb":"[200, 200, 20, 255]",
                   "color_helmets":"#457dff",
                   "color_helmets_rgb":"[200, 200, 20, 255]",
                   "color_gloves":"#457dff",
                   "color_gloves_rgb":"[200, 200, 20, 255]",
                   "color_rings":"#457dff",
                   "color_rings_rgb":"[200, 200, 20, 255]",
                   "color_amulets":"#457dff",
                   "color_amulets_rgb":"[200, 200, 20, 255]",
                   "color_bodies":"#457dff",
                   "color_bodies_rgb":"[200, 200, 20, 255]",
                   "color_boots":"#457dff",
                   "color_boots_rgb":"[200, 200, 20, 255]",
                   }


    cfg["api"] = {"CLIENT_ID":"chipytools",
                  "CLIENT_SECRET":"AskChipyForThis",
                  "SCOPE":"account:profile account:characters account:stashes account:item_filter",
                  "REDIRECT_URI":"https://chipy.dev/poe_auth.html",
                  "TOKEN":"",
                  }
    cfg.read(CFG_FILENAME)

def get(section:str, key:str) -> str:
    return cfg.get(section, key, fallback="MISSING")

def set(section:str, key:str, value:str):
    cfg[section][key] = value
    save()

if __name__ == "__main__":
    print(get("api","client_id"))
    load()
    print(get("api","client_id"))
    save()


import sys
import subprocess

SCRIPT_NAME = "Chipy's PathOfExile Chaos Tool"
installDependencyErrors = 0
installDependencyMessage = ""

# List of packages to install with pip
dependenciesInstall = ["requests","PyQt5", "websockets"]

# List of packages to update with pip
dependenciesUpdate = ["PyQt5"]

# Make sure pip is updated
print("Checking pip is updated...")
try:
    subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", "pip"])
except Exception as e:
    error = "ERROR: Unable to update pip."
    print(error, e)
    installDependencyMessage += f"    - {error}\n"
    installDependencyErrors += 1

# Install packages
for dependency in dependenciesInstall:
    print(f"\nInstalling {dependency}...")
    try:
        subprocess.check_call([sys.executable, "-m", "pip", "install", dependency])
    except Exception as e:
        error = f"ERROR: Unable to install {dependency}."
        print(error, e)
        installDependencyMessage += f"    - {error}\n"
        installDependencyErrors += 1

# Update packages
for dependency in dependenciesUpdate:
    print(f"\nUpdating {dependency}...")
    try:
        subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", dependency])
    except Exception as e:
        error = f"ERROR: Unable to update {dependency}."
        print(error, e)
        installDependencyMessage += f"    - {error}\n"
        installDependencyErrors += 1


if installDependencyErrors == 0:
    # Print finished with no errors
    print(f"\n\nPython Dependencies for {SCRIPT_NAME} successfully installed.\n\nYou can now run the main program with:\n    python main.py\n\nOr by double clicking on _START_HERE\n")
    input("Press Enter to close this window...")
else:
    # Report the errors found
    print(f"\n\nFailed to install Python Dependencies for {SCRIPT_NAME}.\n\nEncountered the following errors:")
    print(installDependencyMessage)
    print(f"You must fix these errors to use the {SCRIPT_NAME}.\n")
    print("Feel free to reach out to Chipy#2023 for help")
    input("Press Enter to close this window...")

